============
Installation
============

At the command line::

    $ easy_install trellostats

Or, if you have virtualenvwrapper installed::

    $ mkvirtualenv trellostats
    $ pip install trellostats